//////////////////////////////////////////////////////////////////////////////
//
//	GameException.cpp
//	Implementation for the cGameException class.
//
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#include "GameException.h"

//////////////////////////////////////////////////////////////////////////////
//
// -	CONSTRUCTOR
//
//	ARGS:	szMessage,		Message to return to user.
//			szFile,			File location of error.
//			lLineNumber,	Line number (of file) location of error.
//
//////////////////////////////////////////////////////////////////////////////
cGameException::cGameException(const char *szMessage, const char* szFile, 
	long lLineNumber)
{
	m_sMessage = szMessage;

	addToCallStack(szFile, lLineNumber);
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cGameException::~cGameException() throw()
{
	m_vsCallStack.clear();
}

//////////////////////////////////////////////////////////////////////////////
//
// Builds error message.
//
//	RETURNS:	A formatted error message.
//
//////////////////////////////////////////////////////////////////////////////
const char* cGameException::what() const throw()
{ 
	// Start of message is the specific user message.
	m_sFormattedMessage = m_sMessage;


	// Add call stack to message.
	if (m_vsCallStack.size() > 0)
	{
		m_sFormattedMessage += string("\n\nCALL STACK:");

		// Loop through call stack messages, adding to final output.
		// (Use index as an iterator has issues in a const method.)
		for (	unsigned int iStackPosition=0; 
				iStackPosition < m_vsCallStack.size(); 
				iStackPosition++)
		{
			m_sFormattedMessage += string("\n");
			m_sFormattedMessage += m_vsCallStack[iStackPosition];
		}
	}

	return m_sFormattedMessage.c_str();
}



//////////////////////////////////////////////////////////////////////////////
//
// Add information to call stack.
//
//	ARGS:	szFile,			Source file name.
//			lLineNumber,	Line number in source file.
//
//////////////////////////////////////////////////////////////////////////////
void cGameException::addToCallStack(const char *szFile, long lLineNumber)
{	
	char szTemp[10];						// Buffer when converting from # to string.
	string sNewEntry(szFile);	// File/line combo being added to stack.

	// Check to see if a file name was passed in.
	if (sNewEntry.length() < 1)
	{
		// Change file name to a default if it is blank.
		sNewEntry = "Unavailable";
	}
	else
	{
		// Since a file name was passed in, add line number.
		sNewEntry += string(" : ");
		sprintf(szTemp, "%u", lLineNumber); // add line #
		sNewEntry += szTemp;
	}
	
	m_vsCallStack.push_back(sNewEntry);	// Add complete message to stack.
}


//////////////////////////////////////////////////////////////////////////////
//
// Output exception information into a log file.
//
//////////////////////////////////////////////////////////////////////////////
void cGameException::dumpLog()
{
	/*
	FILE* logfile;
	logfile = fopen("error.txt", "w");	// open the log file

	if (!logfile) { 
			fprintf(stderr, "Can't open error log file error.txt!\n");
			return;
	}
	
	fprintf(stderr, "%s\n", what());	// print error message
	fclose(logfile);					// close file*/
	printf("Logging doesnt exist in dreamcast version: Error is\n%s\n", what());
}
// vi:set ts=3:
