//////////////////////////////////////////////////////////////////////////////
//
//	GameException.h
//	Defines for the cGameException class.
//
//	-	Whenever an error occurs in the game, throw an object of this class.
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

// Turn off 4786: "identifier was truncated to '255' characters..."
#ifdef WIN32
#pragma warning(disable:4786)
#endif

#ifndef __GAMEEXCEPTION_H__
#define __GAMEEXCEPTION_H__

#include "inc/system.h"

class cGameException : public exception
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
protected:	
	string						m_sMessage;		// Message returned to user.
	vector<string>	m_vsCallStack;	// Call stack.

	// A complete message to user.
	// Since this is built in a const method it must be mutable.
	mutable string m_sFormattedMessage;

	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
protected:
	cGameException();	// Default constructor not creatable.

public:
	// Constructor
	cGameException(const char *szMessage, const char* szFile = NULL, 
		long lLineNumber = -1);
	
	// Destructor
	virtual ~cGameException() throw();

	// Extractor to obtain error message.
	virtual const char* what() const throw();

	// Add information to call stack.
	virtual void addToCallStack(const char *szFile, long lLineNumber);

	// Output exception information into a log file.
	virtual void dumpLog();
};



//////////////////////////////////////////////////////////////////////////////
//
//	Macros
//
//	DO NOT WORK UNDER DREAMCAST
//
//////////////////////////////////////////////////////////////////////////////

// Macro to use in order to throw a game exception with "where" info.
/*#define THROW_GAME(szMessage) \
	throw cGameException(szMessage, __FILE__, __LINE__);

// Same as above, but appends an integer value to end of message.
#define THROW_GAME_INT(szMessage,iValue) \
{\
	string _sErrorMessage(szMessage); \
	_sErrorMessage += string("Value = FIXME, iValue");\
	THROW_GAME(_sErrorMessage.c_str());\
}

// Macro which start a contained block of code, checking if an exception is
//	thrown that was unexpected. (But aren't all expections unexpected? haha)
#define BEGIN_ERRORHANDLER_GAME	\
	try {

// Macro which ends a contained block of code, throwing game exceptions it
// catches up the chain.  Unhandled exceptions are caught, thrown away, and
// replaced with a game exception.
#define END_ERRORHANDLER_GAME																				\
	}catch(const cGameException &oGameException){													\
		const_cast<cGameException&>(oGameException).addToCallStack(__FILE__, __LINE__);	\
		throw oGameException;																				\
	}catch(const length_error){																		\
		THROW_GAME("Unexpected length error exception thrown.");									\
	}catch(const domain_error){																		\
		THROW_GAME("Unexpected domain error exception thrown.");									\
	}catch(const out_of_range){																		\
		THROW_GAME("Unexpected domain error exception thrown.");									\
	}catch(const bad_alloc){																			\
		THROW_GAME("Unexpected bad alloc exception thrown.");										\
	}catch(const range_error){																		\
		THROW_GAME("Unexpected range error exception thrown.");									\
	}catch(const overflow_error){																	\
		THROW_GAME("Unexpected overflow error exception thrown.");								\
	}catch(const underflow_error){																	\
		THROW_GAME("Unexpected underflow error exception thrown.");								\
	}catch(const logic_error){																		\
		THROW_GAME("Unexpected logic error exception thrown.");									\
	}catch(const runtime_error){																	\
		THROW_GAME("Unexpected runtime error exception thrown.");								\
	}catch(const bad_exception){																	\
		THROW_GAME("Unexpected bad exception thrown.");												\
	}catch(...){																								\
		THROW_GAME("Unexpected exception thrown.  The exception type is unknown.")}

*/
		
// Use this between a begin/end pair to give a finer grain of detail to where
// an unexpected error is occuring.
#define CONTINUE_ERRORHANDLER	\
	END_ERRORHANDLER_GAME		\
	BEGIN_ERRORHANDLER_GAME	

// dreamcast hacks
#define END_ERRORHANDLER_GAME 
#define BEGIN_ERRORHANDLER_GAME

inline void THROW_GAME(const char* s) { 
		char buf[256];
		sprintf(buf, "%s", s);
		bfont_draw_str(vram_s+70*640+0, 640,0, buf); 
}

inline void THROW_GAME_INT(const char* s, int iValue) {
		char buf[256];
		sprintf(buf, "%s%i", s, iValue);
		bfont_draw_str(vram_s+70*640+0, 640,0, buf);
}
	
#endif // __GAMEEXCEPTION_H__
// vi:set ts=3:
