//////////////////////////////////////////////////////////////////////////////
//
// eventData.cpp
//	Implementation of the cEventData class.
//
//	-	Handles reading data for events from a disk and prepares them to be
//		used in the game.
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#include "eventData.h"

//////////////////////////////////////////////////////////////////////////////
//
//	-	CONSTRUCTOR
//	-	Loads an event from disk.
//
//		Offset	Size		Info
//		------	------	-------------------------------------------------
//		0			1			Which sprite this event is linked to. (0 = none)
//		1			1			Type of event: see zeldaEventIDs.h
//		2			1			Target of event, either an event or map (optional)
//		3			1			Target screen X-coordinate of portal events
//		4			1			Target screen Y-coordinate of portal events
//		5			1			Target screen template of portal events
//		6			1			Target tile X-coordinate of portal events
//		7			1			Target tile Y-coordinate of portal events
//
//	ARGS:	pFileHandle,	A C-style file handle open and pointing to event
//								data.
//
//	POST:	Member variables initialized based on data from file.
//
//	THROWS:	cGameError,	If file handle is not initialize or failure during
//								reading of the event data.
//
//////////////////////////////////////////////////////////////////////////////
cEventData::cEventData(FILE* pFileHandle)
{
	BEGIN_ERRORHANDLER_GAME

	char szData[8];		// Holds data from file


	// Make sure file handle is legal.
	if (pFileHandle == NULL) {
		printf("Empty file handle given to event data.");
	}

	// Read in header values for this screen object.
	if(	fread(&szData, 1, sizeof(szData), pFileHandle) != 
			sizeof(szData)	)
		printf("Unable to properly read event data.");

	// Attribute determining what sprite the event is linked to.  If 0, the
	// event is linked to the screen, not a specific sprite.
	m_ySpriteID			= szData[0];

	// Attribute determining type of event.
	m_yEventType		= szData[1];

	// Attributes determining target of event.
	m_yTargetID			= szData[2];
	m_yTargetScreenX	= szData[3];
	m_yTargetScreenY	= szData[4];
	m_yTargetTemplate = szData[5];

	END_ERRORHANDLER_GAME
}

// Retrieve the event type.
/*inline*/ BYTE	cEventData::getEventType() {
	return m_yEventType;		
}

// Retrieve the linked sprite ID.
/*inline*/ BYTE	cEventData::getSpriteID() {
	return m_ySpriteID;		
}

// Retrieve the target ID.
/*inline*/ BYTE	cEventData::getTargetID() {
	return m_yTargetID;		
}

// Retrieve target screen coordinates for portals.
/*inline*/ BYTE	cEventData::getTargetScreenX() { 
	return m_yTargetScreenX;	
}
/*inline*/ BYTE	cEventData::getTargetScreenY(){
	return m_yTargetScreenY;	
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cEventData::~cEventData()
{	
}
// vi:set ts=3:
