//////////////////////////////////////////////////////////////////////////////
//
// eventData.cpp
//	Implementation of the cEventData class.
//
//	-	Handles reading data for events from a disk and prepares them to be
//		used in the game.
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#ifndef __EVENTDATA_H__
#define __EVENTDATA_H__

#include "inc/system.h"
#include "inc/misc.h"

#include "GameException.h"

// One single screen object.
class cEventData  
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
protected:
	BYTE	m_ySpriteID;			// ID of event's sprite (0 for none).
	BYTE	m_yEventType;			// Type of event.
	BYTE	m_yInitState;			// Initial state of event.
	BYTE	m_yTargetID;			// ID of target (event, map, or 0 for none.)
	BYTE	m_yTargetScreenX;		// X coord of target screen for portals.
	BYTE	m_yTargetScreenY;		// Y coord of target screen for portals.
	BYTE	m_yTargetTemplate;	// Target template for portals.


	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
private:
	cEventData();	// Default constructor non-creatable.

public:
	cEventData(FILE* pFileHandle);	// Constructor
	virtual ~cEventData();				// Destructor


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////

	// Retrieve the event type.
	/*inline*/ BYTE	getEventType();		
	// Retrieve the linked sprite ID.
	/*inline*/ BYTE	getSpriteID();	
	// Retrieve the target ID.
	/*inline*/ BYTE	getTargetID();
	// Retrieve target screen coordinates for portals.
	/*inline*/ BYTE	getTargetScreenX();
	/*inline*/ BYTE	getTargetScreenY();
};

#endif // __EVENTDATA_H__
// vi:set ts=3:
