//////////////////////////////////////////////////////////////////////////////
//
// eventDialogue.h
//	Defines for the cEventDialogue class.
//
//	-	Handles events in which dialogue (text) is given to the player by
//		displaying it on the screen.
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#ifndef __EVENTDIALOGUE_H__
#define __EVENTDIALOGUE_H__

#include "GameException.h"
#include "event.h"
#include "screen.h"
#include "map.h"
#include "eventData.h"
#include "gameState.h"

// Time delay between letters, in milliseconds
const int iLETTER_TIMER_DELAY =		100;

// Maximum characters allowed in a dialogue line
const int iLINE_MAX_CHARACTERS =		22;

class cEventDialogue : public cEvent  
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
private:
	int			m_iTargetStringID;	// ID of string from table.
	int			m_iCurrentLength;		// Current length of string.
	int			m_iCurrentString;		// String being drawn to screen.
	unsigned int			m_dwTimeDelay;			// Current time delay.
	string	m_szCurrentString;	// String being displayed on screen.

	// Vectors that make up complete string.
	vector<string>	m_vszFullString;
	
	vector<int>	m_viStringX;	// Array for tracking message locations.
	vector<int>	m_viStringY;	// Array for tracking message locations.


	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
private:
	cEventDialogue() {}	// Default constructor non-creatable.

public:
	// Constructor
	cEventDialogue( cGameState* pGameState, cScreen* pScreen, cEventData& oEventData );

	// Destructor
	virtual ~cEventDialogue();

	
	void update();	// Update a triggered dialog event.
	void reset();	// Reset the triggered dialog event.


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////
	
	// Retrieve the ID for the target string.
	/*inline*/ int getTargetStringID();	

	// Retrieve the strings.
	/*inline*/ string* getFullString( int iStringIDNumber );

	// Obtain the current string.
	/*inline*/ string* getCurrentString();

};

#endif // __EVENTDIALOGUE_H__

// vi:set ts=3:
