//////////////////////////////////////////////////////////////////////
// eventFactory.cpp: implementation of the cEventFactory class.
//////////////////////////////////////////////////////////////////////

#include "eventFactory.h"

//////////////////////////////////////////////////////////////////////////////
//
//	CONSTRUCTOR
//
//	ARGS:	pGameState,	Pointer to game state object.
//
//	POST:	m_pGameState,	Set to the game state object.
//
//////////////////////////////////////////////////////////////////////////////
cEventFactory::cEventFactory( cGameState* pGameState )
{
	m_pGameState = pGameState;
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cEventFactory::~cEventFactory()
{

}

//////////////////////////////////////////////////////////////////////////////
//
// Constructs an event with attributes based on data contained within the
//	initializing eventData object.
//
//	ARGS:	oEventData,	Reference to a populated event data object.
//
//	RETURNS:	A specific event type (derived from cEvent).
//
//	THROWS:	cGameException,	Unknown data in the event type.
//
//////////////////////////////////////////////////////////////////////////////
cEvent* cEventFactory::create(cScreen* pScreen, cEventData& oEventData)
{
	BEGIN_ERRORHANDLER_GAME
	

	cEvent* pEvent = NULL;		// The event to return.


	// Determine which sprite set this sprite belongs to.
	switch( oEventData.getEventType() )
	{
		// Portal without animation.
		case EVENT_TYPE_PORTAL_TELEPORT_ACTIVE:	// fall through...
		case EVENT_TYPE_PORTAL_TELEPORT_INACTIVE:	// fall through...
		// Portal with walk animation.
		case EVENT_TYPE_PORTAL_WALK_ACTIVE:
		case EVENT_TYPE_PORTAL_WALK_INACTIVE:
			pEvent = new cEventPortal(m_pGameState, pScreen, oEventData);
			break;
		case EVENT_TYPE_DIALOGUE:
			pEvent = new cEventDialogue(m_pGameState, pScreen, oEventData);
			break;
		// ???KWB - add support for other events.

		// An unhandled event type, error out.
		case EVENT_TYPE_UNDEFINED: // fall through...
		default:
		{
			THROW_GAME_INT("Unknown event type value passed to event factory.",
				oEventData.getEventType() );
			break;
		}
	}

	return pEvent;

	END_ERRORHANDLER_GAME
}
// vi:set ts=3:
