//////////////////////////////////////////////////////////////////////////////
//
// eventPortal.cpp
//	Implementation of the cEventPortal class.
//
//////////////////////////////////////////////////////////////////////////////

#include "eventPortal.h"    // Defines for this class.

// Defines for forward delcarations.
#include "eventData.h"
#include "gameState.h"

//////////////////////////////////////////////////////////////////////////////
//
// CONSTRUCTOR
//
//	ARGS:	pGameState,		Game state object.
//			pScreen,			The screen object in which this portal event exists.
//			oEventData,		Reference to a populated event data object.
//
//////////////////////////////////////////////////////////////////////////////
cEventPortal::cEventPortal(	cGameState* pGameState, cScreen* pScreen, 
										cEventData& oEventData )
	:	cEvent( pGameState, pScreen, oEventData )
{
	// Set target map ID
	m_iTargetMapID = oEventData.getTargetID();

	// Set initial state to inactive
	m_eState = EVENT_INACTIVE;

	// Since target ID is given according to order of screens in the map,
	// a little mathematical trickery is needed ot get coords
	// ???KWB -- This could be very tricky, since the map hasn't been created yet...
	m_iTargetScreenX = oEventData.getTargetScreenX();
	m_iTargetScreenY = oEventData.getTargetScreenY();
}


//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cEventPortal::~cEventPortal()
{
}

//////////////////////////////////////////////////////////////////////////////
//
//	Triggers event, and activates target
// 
//	POST:	m_pTargetMap -- Map becomes set
//			m_pTargetScreen -- Screen becomes set, and Link teleports to it
//
//////////////////////////////////////////////////////////////////////////////
void cEventPortal::trigger()
{
	// Trigger the portal event, and set the game to portal state
	m_eState = static_cast< eEVENT_STATE >(m_eState | EVENT_TRIGGERED);
	m_pGameState->setState( PORTAL_GAME );
	m_pGameState->setPortalState( PORTAL_INIT );
	m_pGameState->setTriggeredPortal( this );

}
///////////////////////////////////////////////////////////////////////////
//	ACCESSORS
///////////////////////////////////////////////////////////////////////////
// Retrieve the ID for the target map
int cEventPortal::getTargetMapID()		{ return m_iTargetMapID;	}

// Retrieve the locations of the target screen
int cEventPortal::getTargetScreenX()	{ return m_iTargetScreenX;	}
int cEventPortal::getTargetScreenY()	{ return m_iTargetScreenY;	}

// vi:set ts=3:
