//////////////////////////////////////////////////////////////////////////////
//
//	zeldaSpriteIDs.h
//	Defines for the cWindow class.
//
// -	ID's to of each sprite corresponding to position in the sprite's
//		graphic file.
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#ifndef	__ZELDASPRITEIDS_H__
#define	__ZELDASPRITEIDS_H__


//////////////////////////////////////////////////////////////////////////////
//	IDs of maps used in the game.
//////////////////////////////////////////////////////////////////////////////
enum eMAPS
{
	MAP_OVERWORLD = 0,
	MAP_CAVES,
	MAP_DUNGEON1,
	MAP_DUNGEON2,
	MAP_DUNGEON3,
	MAP_DUNGEON4,
	MAP_DUNGEON5,
	MAP_DUNGEON6,
	MAP_DUNGEON7,
	MAP_DUNGEON8,
	MAP_DUNGEON9
};



//////////////////////////////////////////////////////////////////////////////
//	Defines for sets of sprites.
//////////////////////////////////////////////////////////////////////////////
enum eSCREEN_TYPE
{
	SCREEN_TYPE_NORMAL = 0,
	SCREEN_TYPE_LEAVE_MAP_SOUTH,		// Exiting a dungeon, shop, etc...
	SCREEN_TYPE_LOST_WOODS,
	SCREEN_TYPE_LOST_HILLS
};



//////////////////////////////////////////////////////////////////////////////
//	-	Defines the IDs for sets of sprites.
// -	Each set represents a different tile object that holds graphics for the
//		sprites in it's set.
//////////////////////////////////////////////////////////////////////////////
enum eSPRITE_SET
{
	SPRITE_SET_UNDEFINED	= -1,
	SPRITE_SET_MENU,						// Font, and menu graphics
	SPRITE_SET_GOOD_CHARACTERS,		// Link, Zelda, Fairy, Old Man, etc...
	SPRITE_SET_ITEMS,						// All items, weapons, shots, etc...
	SPRITE_SET_OVERWORLD_TILES,		// Background for the overworld
	SPRITE_SET_OVERWORLD_ENEMIES,		// Enemies who reside in the overworld
	SPRITE_SET_DUNGEONS_TILES,			// Background for dungeons
	SPRITE_SET_DUNGEONS_ENEMIES,		// Enemies who reside in dungeons
	SPRITE_SET_DUNGEONS_BOSSES			// Bosses in the dungeons		
};



//////////////////////////////////////////////////////////////////////////////
//	IDs of color sets.
//////////////////////////////////////////////////////////////////////////////
enum eCOLOR_SET
{
	// Generic enums for base classes.  Really these shouldn't exist as sub-
	// classes should override any methods where these variables are used.
	// If any of these values are used in a non-base class then you are doing
	// something wrong!
	COLOR_SET_ONE	= 1,
	COLOR_SET_TWO	= 2,
	COLOR_SET_THREE= 3,
	COLOR_SET_FOUR	= 4,
	
	// Good characters (link, old man, fairy, etc...)
	COLOR_SET_GOOD_CHARACTERS_LIME		=1,
	COLOR_SET_GOOD_CHARACTERS_BLUE		=2,
	COLOR_SET_GOOD_CHARACTERS_BROWN		=3,
	COLOR_SET_GOOD_CHARACTERS_RED			=4,

	// Items (sword, key, heart, etc...)
	COLOR_SET_ITEMS_BLUE						=1,
	COLOR_SET_ITEMS_RED						=2,
	COLOR_SET_ITEMS_GREEN					=3,
	COLOR_SET_ITEMS_BROWN					=4,

	// Overworld screen tiles.
	COLOR_SET_OVERWORLD_TILES_WHITE		=1,
	COLOR_SET_OVERWORLD_TILES_GREEN		=2,
	COLOR_SET_OVERWORLD_TILES_BROWN		=3,
	// ???KWB - Caves have black backdrop
	COLOR_SET_OVERWORLD_TILES_CAVE		=4,

	// Over world enemies.
	COLOR_SET_OVERWORLD_ENEMIES_BLUE		=1,
	COLOR_SET_OVERWORLD_ENEMIES_RED		=2,
	COLOR_SET_OVERWORLD_ENEMIES_BLACK	=3

	// ???TMH - Add other color sets.
};



//////////////////////////////////////////////////////////////////////////////
// -	What collision behavior is demonstrated by the sprite.
//	-	This is a bit mask along a byte boundry.
//////////////////////////////////////////////////////////////////////////////
enum eSPRITE_COLLIDE
{
	SPRITE_COLLIDE_DEFAULT	= 0x00,	// A "clear" sprite
	SPRITE_COLLIDE_SOLID		= 0x01,	// Blocks movement
	SPRITE_COLLIDE_DAMAGE	= 0x02,	// Causes damage to player
	SPRITE_COLLIDE_PLAYER	= 0x04,	// A player sprite
	SPRITE_COLLIDE_ENEMY		= 0x08,	// An enemy sprite
	SPRITE_COLLIDE_SHOT		= 0x10	// A projectile
};



//////////////////////////////////////////////////////////////////////////////
// How a sprite is "spawned" when it first appears.
//////////////////////////////////////////////////////////////////////////////
enum eSPAWN_TYPE
{
	SPAWN_TYPE_TILE_COORDINATE = 0,	// Use x,y as screen tile coordinates.
	SPAWN_TYPE_SCREEN_COORDINATE,		// Use x,y as pixel coordinates.
	SPAWN_TYPE_RANDOM_CLOUD,			// Start on random clear tile as "cloud".
	SPAWN_TYPE_SIDE_SCREEN				// Start on random side screen clear tile.
};



//////////////////////////////////////////////////////////////////////////////
//	ID's for which depth-level to draw sprites.
//////////////////////////////////////////////////////////////////////////////
enum eZ_PLANE
{
	Z_PLANE_CEILING	= 8,		// Doorways in dungeons.
	Z_PLANE_EFFECTS	= 6,		// Effects (smoke, fire, etc...)
	Z_PLANE_CHARACTER	= 5,		// Link, enemies, items, etc...
	Z_PLANE_SHOT		= 3,		// Shots (sword, arrows,etc...)
	Z_PLANE_FLOOR		= 2,		// (default) Ground
	Z_PLANE_SECRET		= 0		// Cave/secret/dungeon entrances
};



//////////////////////////////////////////////////////////////////////////////
//
// -	Directions in which a sprite can move.
// -	Also an offset for which sprite tile to draw.  This means that when
//		adding new sprites, the first one needs to point down, second up,
//		third left, etc...
//
//////////////////////////////////////////////////////////////////////////////
enum eDIRECTION
{
	DOWN			= 0,
	UP				= 1,
	LEFT			= 2,
	RIGHT			= 3,
	DOWN_LEFT	= 4,
	DOWN_RIGHT	= 5,
	UP_LEFT		= 6,
	UP_RIGHT		= 7
};



//////////////////////////////////////////////////////////////////////////////
//	Determines what type of item(s) is gained when an enemy is killed.
//////////////////////////////////////////////////////////////////////////////
enum eGOODIES
{
	GOODIES_NONE	= 0,		// You get absolutely nothing!
	GOODIES_BASIC	= 1		// Coin, Bomb, fairy, maybe even a clock or fairy
};


//////////////////////////////////////////////////////////////////////////////
//
//	Sprite IDs: GOOD CHARACTERS
//
//////////////////////////////////////////////////////////////////////////////
#define	ID_LINK						0x00	// Link with small shield.
#define	OFFSET_LINK_SHIELD		0x08	// Same as above, but with big shield.
#define	ID_LINK_ATTACK				0x10	// Link attacking.
#define	ID_LINK_ITEM_GRAB			0x14	// Link holding up an item.
#define	ID_LINK_TRIFORCE_GRAB	0x15	// Link holding up triforce piece.
#define	ID_ZELDA						0x18	// Princess Zelda
#define	ID_FAIRY						0x1a	// Fairy
#define	ID_OLD_WOMAN				0x1c	// Old woman
#define	ID_HAIRY_GUY				0x1d	// Hairy (shop?) guy
#define	ID_OLD_MAN_1				0x1e	// Old man #1
#define	ID_OLD_MAN_2				0x1f	// Old man #2



//////////////////////////////////////////////////////////////////////////////
//
//	Sprite IDs: ITEMS
//	Defintions from http://www.lanceandeskimo.com/chefelf/gam_zel_items.shtml
//
//////////////////////////////////////////////////////////////////////////////

#define	ID_ITEM_MAGICAL_SWORD	0x00	// Still sprite for magic sword
#define	ID_ITEM_MAGICAL_SHIELD	0x01	// Magic (larger) shield
#define	ID_ITEM_SWORD				0x02	// Sword
#define	ID_ITEM_RUPY				0x06	// Rupy
#define	ID_ITEM_TRIFORCE			0x07	// Piece of the Triforce
#define	ID_ITEM_BOOMERANG			0x08	// Boomerang
#define	ID_ITEM_MAGICAL_ROD		0x10	// Magical Rod
#define	ID_ITEM_ROD_SHOT			0x14	// Shot from magical rod
#define	ID_ITEM_ARROW				0x18	// Arrow
#define	ID_ITEM_BOW_AND_ARROW	0x1C	// Bow and arrow
#define	ID_ITEM_RECORDER			0x1D	// It's not a flute, it's a recorder.
#define	ID_ITEM_WHIRLWIND			0x1E	// Wind from blowing the recorder.
#define	ID_ITEM_BOMB				0x20	// Bomb
#define	ID_ITEM_CANDLE				0x21	// Candle
#define	ID_ITEM_BOOK_OF_MAGIC	0x22	// Book of magic
#define	ID_ITEM_POTION				0x23	// Potion
#define	ID_ITEM_FOOD				0x24	// Food
#define	ID_ITEM_POWER_BRACELET	0x25	// Power bracelet
#define	ID_ITEM_RING				0x26	// Ring
#define	ID_ITEM_COMPASS			0x27	// Compass
#define	ID_ITEM_MAP					0x28	// Map
#define	ID_ITEM_KEY					0x29	// Key
#define	ID_ITEM_MAGICAL_KEY		0x2A	// Magical key (opens all doors)
#define	ID_ITEM_HEART_CONTAINER 0x2B	//	Heart container (adds max hearts)
#define	ID_ITEM_HEART				0x2C	// Heart
#define	ID_ITEM_STEP_LADDER		0x30	// Step ladder (crossing one tile)
#define	ID_ITEM_RAFT				0x31	// Raft (travel across water)
#define	ID_ITEM_MAGICAL_CLOCK	0x32	// Clock (freezes time)
#define	ID_ITEM_CLOUD				0x33	// Cloud puff
#define	ID_ITEM_SPARKLE			0x36	// Sparkle (when enemies die)
#define	ID_ITEM_FIRE				0x38	// Fire in caves / from lattern


//////////////////////////////////////////////////////////////////////////////
//
//	Sprite IDs: OVERWORLD
//
//////////////////////////////////////////////////////////////////////////////

#define	ID_MOUNT_TOP_LEFT			0x00
#define	ID_MOUNT_TOP				0x01
#define	ID_MOUNT_TOP_RIGHT		0x02
#define	ID_MOUNT_BOTTOM_LEFT		0x03
#define	ID_MOUNT_BOTTOM			0x04
#define	ID_MOUNT_BOTTOM_RIGHT	0x05
#define	ID_ROCK						0x06
#define	ID_GRAVESTONE				0x07
#define	ID_BUSH						0x08
#define	ID_ARMOS_STATUE			0x09
#define	ID_TREE_TOP_LEFT			0x0a
#define	ID_TREE_TOP_FACE			0x0b
#define	ID_TREE_TOP_RIGHT			0x0c
#define	ID_TREE_BOTTOM_LEFT		0x0d
#define	ID_TREE_BOTTOM_RIGHT		0x0e
#define	ID_DUNGEON_TOP_LEFT		0x0f
#define	ID_DUNGEON_FACE_1			0x10
#define	ID_DUNGEON_FACE_2			0x11
#define	ID_DUNGEON_TOP_RIGHT		0x12
#define	ID_DUNGEON_BOTTOM_LEFT	0x13
#define	ID_DUNGEON_BOTTOM_RIGHT	0x14
#define	ID_LAKE_TOP_LEFT			0x15
#define	ID_LAKE_TOP					0x16
#define	ID_LAKE_TOP_RIGHT			0x17
#define	ID_LAKE_LEFT				0x18
#define	ID_LAKE_CENTER				0x19
#define	ID_LAKE_RIGHT				0x1a
#define	ID_LAKE_BOTTOM_LEFT		0x1b
#define	ID_LAKE_BOTTOM				0x1c
#define	ID_LAKE_BOTTOM_RIGHT		0x1d
#define	ID_WATERFALL_TOP			0x1e
#define	ID_WATERFALL_BOTTOM		0x1f
#define	ID_WATER_EDGE_TOP_LEFT	0x20
#define	ID_WATER_EDGE_TOP_RIGHT		0x21
#define	ID_WATER_EDGE_BOTTOM_LEFT	0x22
#define	ID_WATER_EDGE_BOTTOM_RIGHT	0x23
#define	ID_DOCK						0x24
#define	ID_PLAIN						0x25
#define	ID_SAND						0x26
#define	ID_STAIRS					0x27
#define	ID_CAVE_STEPS				0x28
// ???KWB - Was ID_CAVE_ENTERANCE, and it was bothering me, so I changed it :)
#define	ID_CAVE_ENTRANCE			0x29



//////////////////////////////////////////////////////////////////////////////
//
//	Sprite IDs: OVERWORLD ENEMIES 
//
//////////////////////////////////////////////////////////////////////////////

#define	ID_OCTOROCK					0x00
#define	ID_MOBLIN					0x08	
#define	ID_ZORA						0x10
#define	ID_PEAHAT					0x12
#define	ID_TECTITE					0x14
#define	ID_EMERGE					0x18	// Leever and Zora emerge images
#define	ID_LEEVER_EMERGE			0x1A
#define	ID_LEEVER					0x1B
#define	ID_ARMOS						0x20
#define	ID_CENTAUR					0x28
#define	ID_GHOST						0x30
#define	ID_FALLING_ROCK			0x34





// ???TMH - Finish adding enemies.

// Everything below this is what was kept in the old file and needs to
//	be updated to the new values....

#define	KEESE			0x10		// Underworld Characters
#define	KEESE_MOTHER	0x11
#define	GEL				0x12
#define	GEL_MOTHER		0x13
#define	STALFOS			0x14
#define	STALFOS2		0x15
#define	TRAP			0x16
#define	WALLMASTER		0x17
#define	RED_GORIYA		0x18
#define	BLUE_GORIYA		0x19
#define	SNAKE			0x1a
#define	SNAKE2			0x1b
#define	FIRE_SNAKE		0x1c
#define	BUBBLE			0x1d
#define	RED_BUBBLE		0x1e
#define	BLUE_BUBBLE		0x1f
#define	RED_DARKNUT		0x20
#define	BLUE_DARKNUT	0x21
#define	MUMMY			0x22
#define	POLS_VOICE		0x23
#define	RED_WIZZROBE	0x24
#define	BLUE_WIZZROBE	0x25
#define	LIKE_LIKE		0x26
#define	RED_LANMOLA		0x27
#define	BLUE_LANMOLA	0x28
#define	LEFT_GARGOYLE	0x29
#define	RIGHT_GARGOYLE	0x2a
#define EYEBALL_BABY	
#define	EYEBALL_MOTHER	

#define	AQUAMENTUS		0x30		// Underworld Bosses
#define	DODONGO			0x31
#define	MANHANDLA		0x32
#define	GLEEOK			0x33
#define	DIGDOGGER		0x34
#define	RED_GOHMA		0x35
#define	BLUE_GOHMA		0x36
#define	GANON			0x37

#define	OLD_MAN
#define	OLD_WOMAN


#endif // __ZELDASPRITEIDS_H__
