//////////////////////////////////////////////////////////////////////////////
//
//	inventory.h
//	Defines for the cInventory class.
//
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

// Turn off 4786: "identifier was truncated to '255' characters..."
#ifdef WIN32
#pragma warning(disable:4786)
#endif

#ifndef __INVENTORY_H__
#define __INVENTORY_H__

#include "inc/system.h"

#include "gameState.h"				// Support for main game state object.
#include "objectInventoryItem.h"

// Forward defines (truly defined later).
class cTiles;
class cObjectLynk;
class cObjectStillSword;
class cObjectInventoryItem;
class cGameState;

class cInventory
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
private:

	cObjectStillSword*	m_pSword;		// Link's sword
	cGameState*			m_pGameState;	// Main game state object.
	cTiles*				m_pMenuTiles;	// Graphics for menu, font, etc...
	cTiles*				m_pItemTiles;	// Graphics for weapons, items, etc...

	// Container to organize items.
	vector<cObjectInventoryItem*>	m_vItems;
	vector<cObjectInventoryItem*>::iterator	m_itrCurrentItem;

	int	m_iHeartContainers;			// # of heart containers.
	int	m_iHeartsPerContainer;		// # of hearts per heart container.
	int	m_iMaximumHitPoints;			// # of max hit points.

	int m_iRupees;		// # of rupees to spend.
	int m_iKeys;		// # of keys available.
	int m_iBombs;		// # of bombs available.

	bool m_bMagicKey;	// If the magic key is obtained.


	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
private:
	cInventory();	// Default constructor non-creatable.


public:
	cInventory(cGameState* pGameState);		// Constructor
	virtual ~cInventory();						// Destructor

	void reset();
	void update();
	void draw();	
	
	void nextItem();			// Next item in inventory.
	void previousItem();		// Previous item in inventory.
	bool spendRupee();		// Spend a Rupee.


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////

	// Gives out the sword.
	/*inline*/ cObjectStillSword* getSword() { return m_pSword; }

	// Gives out the selected Inventory Item.
	/*inline*/ cObjectInventoryItem* getCurrentItem()
		{ return *m_itrCurrentItem; }

	// Returns maximum value for HP.
	// ???TMH - This should be maximum hearts, not hit points.
	/*inline*/ int getMaximumHitPoints() { return m_iMaximumHitPoints; }
};


#endif // __INVENTORY_H__
// vi:set ts=3:
