//////////////////////////////////////////////////////////////////////////////
//
//	OBJECTLink.h
//	Defines for the cObjectLynk class.
//
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

// Turn off 4786: "identifier was truncated to '255' characters..."
#ifdef WIN32
#pragma warning(disable:4786)
#endif

#ifndef __OBJECTLINK_H__
#define __OBJECTLINK_H__

#include "inc/system.h"

#include "inventory.h"          
#include "gameState.h"
#include "GameException.h"      // Exception handling.
#include "event.h"              // Base class for all events.
#include "tiles.h"              // Working with images as game tiles.
#include "sprite.h"             // Base class for all sprites.
#include "inc/SpriteIDs.h" 	// IDs for sprites.
#include "objectStillSword.h"

// Forward defines (truly defined later).
class cInventory;
class cGameState;

class cObjectLynk : public cSprite  
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
private:
	// ???TMH - Move all of these out of this class!  They need to be in the
	//				inventory class, and all Link should be told to do is "pose"
	//				when a weapon is activated.
	bool	m_bMagicSheild;						// Does Link have the magic shield?
	bool	m_bIsSwinging;							// Is link in swinging pose?
	bool	m_bSwordStartActivate;				// Attempt to activate sword?
	bool	m_bActivateSwordButtonReleased;  // has player released sword attack?
					 // Has Link attempted to start tossing boomerang?
	bool	m_bInventoryItemStartActivate;
					 // Is the B Item button released?
	bool	m_bActivateInventoryItemButtonReleased;
	bool	m_bInventoryItemStartSelectNext;		// Change Inventory Item?
	bool	m_bSelectNextInventoryItemButtonReleased;	// Item button released?
	
	float	m_fHeightHalf;		// Link's height for bottom only collisions.

	cInventory*			m_pInventory;	// Player's inventory.

	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
private:
	cObjectLynk(){}	//	Default constructor non-creatable

	void updatePlayGame();				// Link's main routine when playing game.
	void getInputFromUser();			// Get input from user playing the game.
	void updateAdjustWalkingGfx();	// Update Link's graphic for walking.
	void recoil();
	void startSwing();					// Start swinging the sword.


public:
	cObjectLynk(cGameState* pGameState, cInventory* pInventory);	// Constructor
	virtual ~cObjectLynk();										// Destructor

	// Implementation of cSprite virtuals...
	bool collide(cSprite*);
	bool eventCollide();
	void reset();
	void update();
	void draw();
	bool isOutOfPlayfield();

	//	Positions Link on the other side of the screen after a recoil.
	void flipScreenPositionAfterScroll();


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////

	//	Is Link in the middle of swing.
	/*inline*/ bool isSwinging() { return (m_lFrozenTimer > 0); }

	//	Determine if Link is at full HP
	/*inline*/ int isAtFullHitPoints() {
		return ( m_iHitPoints == m_pInventory->getMaximumHitPoints() ); }

};


#endif  //  __OBJECTLINK_H__
// vi:set ts=3:
