//////////////////////////////////////////////////////////////////////////////
//
//	OBJECTSparkle.cpp
//	Implementation for the cObjectSparkle class.
//
//	-	Handles sparkles and creation of bounty after enemy dies.
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#include "objectSparkle.h"

// Time offsets in milliseconds for animation.
const long lFRAME2	= 40;
const long lFRAME3	= 80;
const long lFRAME4	= 120;
const long lFRAME5	= 160;
const long lFRAME6	= 200;
const long lFRAME_END= 240;


//////////////////////////////////////////////////////////////////////////////
//
//	CONSTRUCTOR
//
//	ARGS:	pGameState,	Game state.
//			fx,			x position in pixels.
//			fy,			y position in pixels.
//			eGoodie,		What type of item(s) could appear when sparkle ends.
//
//////////////////////////////////////////////////////////////////////////////
cObjectSparkle::cObjectSparkle(
	cGameState* pGameState, float fx, float fy, eGOODIES eGoodie)
{
	// Set member variables from parameters.
	m_pGameState = pGameState;	// Game state
	m_fx = fx;						// Starting X position
	m_fy = fy;						// Starting Y position
	m_eGoodie = eGoodie;			// Item to be produced when sparkle ends.

	// Set graphics set used by this sprite.
	m_pTiles = pGameState->getSpriteSetTiles(SPRITE_SET_ITEMS);

	// Common sprite attributes.
	m_yColorSet			= COLOR_SET_ITEMS_BLUE;				// Color set.
	m_eCollisionMask	= SPRITE_COLLIDE_DEFAULT;			// "Clear" sprite.
	m_eSpawnType		= SPAWN_TYPE_SCREEN_COORDINATE;	// How sprite spawns.
	m_eZ					= Z_PLANE_EFFECTS;					// Z-Plane
	
	cSprite::reset();					// Set infered defaults via base class.

	// No collision detecting performed so zero these out...
	m_fWidth		= 0.0f;
	m_fHeight	= 0.0f;
	m_fEpsilonX = 0.0f;
	m_fEpsilonY = 0.0f;
}


//////////////////////////////////////////////////////////////////////////////
// DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cObjectSparkle::~cObjectSparkle()
{
}


//////////////////////////////////////////////////////////////////////////////
//
//	-	Updates the sparkle.
//
//////////////////////////////////////////////////////////////////////////////
void cObjectSparkle::update()
{
	// Update the animation time with the time that passed.
	m_lAnimationTime += m_pGameState->getTimeLapseMS();

	// Set which of the sprite tiles to draw based on how much time has
	// passed and what color to make it.
	if (m_lAnimationTime > lFRAME_END)
	{
		// Zero "hit points", which will cause removal from active sprites.
		m_iHitPoints = 0;
	}
	else if (m_lAnimationTime > lFRAME6 )
	{
		m_iAnimateOffset	= 0;
		m_yColorSet			= COLOR_SET_ITEMS_BROWN;
	}
	else if (m_lAnimationTime > lFRAME5 )
	{
		m_iAnimateOffset	= 0;
		m_yColorSet			= COLOR_SET_ITEMS_RED;
	}
	else if (m_lAnimationTime > lFRAME4 )
	{
		m_iAnimateOffset	= 1;
		m_yColorSet			= COLOR_SET_ITEMS_BLUE;
	}
	else if (m_lAnimationTime > lFRAME3 )
	{
		m_iAnimateOffset	= 1;
		m_yColorSet			= COLOR_SET_ITEMS_RED;
	}
	else if (m_lAnimationTime > lFRAME2 )
	{
		m_iAnimateOffset	= 0;
		m_yColorSet			= COLOR_SET_ITEMS_BROWN;
	}
	else							// Frame 0.
	{
		m_iAnimateOffset	= 0;
		m_yColorSet			= COLOR_SET_ITEMS_BLUE;
	}

}


//////////////////////////////////////////////////////////////////////////////
//
//	-	Draws the sparkle after an enemy dies.
//
//////////////////////////////////////////////////////////////////////////////
void cObjectSparkle::draw()
{
	BEGIN_ERRORHANDLER_GAME

	// Draw sparkle.
	m_pTiles->draw(m_fx, m_fy, Z_PLANE_CHARACTER,
		ID_ITEM_SPARKLE + m_iAnimateOffset,
		m_yColorSet);

	END_ERRORHANDLER_GAME

}
// vi:set ts=3:
