//////////////////////////////////////////////////////////////////////////////
//
//	screen.h
//	Defines for the cScreen class.
//
//	-	Holds a series of sprites in a grid format to make up a "screen".
//	-	Holds sprites (enemies, items, etc...) which make up screen.
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#ifndef __SCREEN_H__
#define __SCREEN_H__

// Turn off 4786: "identifier was truncated to '255' characters..."
#ifdef WIN32
#pragma warning(disable:4786)
#endif

#include "inc/system.h"
#include "ColorRGB.h"
#include "ColorRGBPalette.h"

// Forward defines (truly defined later).
class cSprite;
class cEvent;
class cMap;
class cGameState;

class cScreen
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
private:	
	BYTE	m_yWidth;		// Width of screen in sprite tiles.
	BYTE	m_yHeight;		// Height of screen in sprite tiles.
	BYTE	m_yType;			// Type of screen.
	BYTE	m_yEvents;		// Number of events on screen.
	BYTE	m_yTemplateID;	// ID of the screen template utilized (or none=0x00).

	cMap*	m_pMap;			// Pointer to map for which the screen belongs.

	// Sprites for the current screen.
	vector<cSprite*>	m_vpSprites;
	
	// Sprites which are currently being used.
	vector<cSprite*>	m_vpActiveSprites;

	// Events for the current screen
	vector<cEvent*>		m_vpEvents;


	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
private:
	cScreen(){}		// Default constructor non-creatable.

public:
	// Constructor	
	cScreen(cGameState* pGameState, cMap* pMap, FILE* pFileHandle);	
	
	// Destructor
	virtual ~cScreen();


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////

	// Obtains a copy of the sprites used in the screen.
	/*inline*/ vector<cSprite*> getSprites();

	// Obtains a copy of the events used in the screen
	/*inline*/ vector<cEvent*> getEvents();

	// Retrieve a pointer to a specific sprite.
	/*inline*/ cSprite* getSprite(int iSpriteID);

	// Retrieve a pointer to the screen's map
	/*inline*/ cMap* getMap();
};

#endif // __SCREEN_H__
// vi:set ts=3:
