//////////////////////////////////////////////////////////////////////////////
//
// spriteData.cpp
//	Implementation for the cSpriteData class.
//
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#include "spriteData.h"

//////////////////////////////////////////////////////////////////////////////
//
//	-	CONSTRUCTOR
//	-	Loads a sprite from disk.
//
//		Offset	Size		Info
//		------	------	-------------------------------------------------
//		0			1			Which sprite set this sprite is in.
//		1			1			ID of the sprite.
//		2			1			Color set of sprite (0 = none)
//		3			1			Collide bit mask:	0x01 = sprite is solid
//														0x02 = sprite causes damage
//		4			1			Spawn type:	0 = appears using tile coordinates
//												1 = appears using pixel coordinates
//												2 = randomly on clear tile, using a
//														cloud animation.
//												3 = randomly on clear tile which
//														borders the screen.
//		5			1			Horitzontal position (x)
//		6			1			Vertical position (y)
//		7			1			Z-plane (z)
//
//	ARGS:	pFileHandle,	A C-style file handle open and pointing to sprite
//								data.
//
//	POST:	Member variables initialized based on data from file.
//
//	THROWS:	cGameError,	If file handle is not initialize or failure during
//								reading of the sprite data.
//
//////////////////////////////////////////////////////////////////////////////
cSpriteData::cSpriteData(FILE* pFileHandle)
{
	BEGIN_ERRORHANDLER_GAME

	char szData[8];		// Holds data from file


	// Make sure file handle is legal.
	if (pFileHandle == NULL)
	{
		// Bad file handle.  Throw with an appropriate error message.
		THROW_GAME("Empty file handle given to raw screen tile.");
	}

	// Read in header values for this screen object.
	if(	fread(&szData, 1, sizeof(szData), pFileHandle) != 
			sizeof(szData)	)
	{
		// Error attempting to read screen tile data.
		THROW_GAME("Unable to properly read screen tile data.");
	}

	// Attributes determining what type of sprite this is.
	m_eSpriteSetID		= static_cast<eSPRITE_SET>(szData[0]);
	m_ySpriteID			= szData[1];

	// Attributes determining how sprite behaves.
	m_yColorSet			= szData[2];
	m_eCollisionMask	= static_cast<eSPRITE_COLLIDE>(szData[3]);
	m_eSpawnType		= static_cast<eSPAWN_TYPE>(szData[4]);

	// XXX REMOVE THIS - m_yColorSet OK here.
	//printf("  >> spriteData.cpp m_yColorSet = %i\n", m_yColorSet);

	// Attributes for (starting) screen location.
	m_yStartingX	= szData[5];
	m_yStartingY	= szData[6];
	m_eZ				= static_cast<eZ_PLANE>(szData[7]);


	END_ERRORHANDLER_GAME
}

// Sprite type related...
/*inline*/ eSPRITE_SET cSpriteData::getSpriteSetID()	{
	return m_eSpriteSetID;	
}
/*inline*/ BYTE cSpriteData::getSpriteID() { 
	return m_ySpriteID;
}

// Sprite behavor attributes...
/*inline*/ BYTE	cSpriteData::getColorSet() {
	return m_yColorSet; 
}

/*inline*/ eSPRITE_COLLIDE cSpriteData::getCollideMask() {
	return m_eCollisionMask;
}

/*inline*/ eSPAWN_TYPE cSpriteData::getSpawnType() {
	return m_eSpawnType; 
}

// Position related...
/*inline*/ BYTE	cSpriteData::getX() {
	return m_yStartingX; 
}
/*inline*/ BYTE cSpriteData::getY() {
	return m_yStartingY; 
}
/*inline*/ eZ_PLANE	cSpriteData::getZ() {
	return m_eZ; 
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cSpriteData::~cSpriteData()
{	
}

// vi:set ts=3:
