//////////////////////////////////////////////////////////////////////////////
//
// spriteData.h
//	Defines for the cSpriteData class.
//
//	-	Reads the data from a file which defines a sprite.
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#ifndef __SPRITEDATA_H__
#define __SPRITEDATA_H__

#include "inc/system.h"
#include "inc/misc.h"
#include "inc/id.h"
#include "GameException.h"

// Define type to iterate through collection of sprite data.
class cSpriteData;
typedef vector<cSpriteData*>::iterator SPRITEDATA_ITR;

// One single screen object.
class cSpriteData
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
protected:
	eSPRITE_SET			m_eSpriteSetID;		// ID of graphic set to use.
	BYTE					m_ySpriteID;			// ID of sprite.
	BYTE					m_yColorSet;			// Which color set when drawing.
	eSPRITE_COLLIDE	m_eCollisionMask;		// Collision behavior properties.
	eSPAWN_TYPE			m_eSpawnType;			// How  sprite initially appears.
	BYTE					m_yStartingX;			// Starting horizontal location.
	BYTE					m_yStartingY;			// Starting vertical location.
	eZ_PLANE				m_eZ;						// Z plane (may be negative)

	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
protected:
	cSpriteData();	// Default constructor non-creatable.

public:
	cSpriteData(FILE* pFileHandle);	// Constructor
	virtual ~cSpriteData();				// Destructor

	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////
	// Sprite type related...
	/*inline*/ eSPRITE_SET	getSpriteSetID();
	/*inline*/ BYTE				getSpriteID();		

	// Sprite behavor attributes...
	/*inline*/ BYTE					getColorSet();
	/*inline*/ eSPRITE_COLLIDE	getCollideMask();
	/*inline*/ eSPAWN_TYPE		getSpawnType();

	// Position related...
	/*inline*/ BYTE			getX();
	/*inline*/ BYTE			getY();
	/*inline*/ eZ_PLANE	getZ();
};


#endif // __SPRITEDATA_H__
// vi:set ts=3:
