//////////////////////////////////////////////////////////////////////////////
//
// spriteFactory.cpp
//	Implementation of the cSpriteFactory class.
//
//	-	Creates specific sprite classes based on sprite object information.
//	-	Tabs set to 3 spaces.
//
//////////////////////////////////////////////////////////////////////////////

#include "spriteFactory.h"

//////////////////////////////////////////////////////////////////////////////
//
//	CONSTRUCTOR
//
//	ARGS:	pGameState,	Pointer to game state object.
//
//	POST:	m_pGameState,	Set to the game state object.
//
//////////////////////////////////////////////////////////////////////////////
cSpriteFactory::cSpriteFactory(cGameState* pGameState)
{
	// Set member variables based on parameters.
	m_pGameState = pGameState;
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cSpriteFactory::~cSpriteFactory()
{
}

//////////////////////////////////////////////////////////////////////////////
//
// Constructs a sprite with attributes based on data contained within the
//	initializing spriteData object.
//
//	ARGS:	oSpriteData,	Reference to a populated sprite data object.
//
//	RETURNS:	A specific sprite type (derived from cSprite).
//
//	THROWS:	cGameException,	Unknown data in the sprite type or sprite ID.
//
//////////////////////////////////////////////////////////////////////////////
cSprite* cSpriteFactory::create(cSpriteData& oSpriteData)
{
	BEGIN_ERRORHANDLER_GAME
	

	cSprite* pSprite = NULL;		// The sprite to return.


	// Determine which sprite set this sprite belongs to.
	switch( oSpriteData.getSpriteSetID() )
	{
		// Overworld screen tile sprite.
		case SPRITE_SET_OVERWORLD_TILES:
			pSprite = new cSpriteScreenTile(m_pGameState, oSpriteData);
			break;

		// Overworld enemy sprite.
		case SPRITE_SET_OVERWORLD_ENEMIES:
			// ???TMH - add switch statement to support other enemies.
			pSprite = new cObjectOctorock(m_pGameState, oSpriteData);
			break;

		// An unhandled sprite condition, error out.
		case SPRITE_SET_UNDEFINED: // fall through...
		default:
		{
			THROW_GAME_INT("Unknown sprite set value passed to sprite factory.",
				oSpriteData.getSpriteSetID() );
			break;
		}
	}

	return pSprite;

	END_ERRORHANDLER_GAME
}

// vi:set ts=3:
