//////////////////////////////////////////////////////////////////////////////
//
//	spriteScreenTile.cpp
//	Implementation for the cSpriteScreenTile class.
//
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#include "spriteScreenTile.h"

//////////////////////////////////////////////////////////////////////////////
//
//	CONSTRUCTOR
//
//	ARGS:	pGameState,		Point to game state object.
//			oSpriteData,	Contains data on how to construct sprite.
//
//////////////////////////////////////////////////////////////////////////////
cSpriteScreenTile::cSpriteScreenTile(cGameState* pGameState, 
	cSpriteData& oSpriteData) :	
		cSprite(pGameState, oSpriteData)
{
	// Set which background tile this sprite represents.
	m_ID = oSpriteData.getSpriteID();

	// Makes sure we are attempting to spawn the only way a background tile
	// can, which is by tile coordinates.
	if (m_eSpawnType != SPAWN_TYPE_TILE_COORDINATE)
	{
		THROW_GAME("A background tile was attempted to be created using a "
			"spawn type other than SPAWN_TYPE_TILE_COORDINATE");
	}

	// Adjust X and Y to be a pixel position (instead of a tile position).

	// Position times the width of eahc tile.
	m_fx = (m_fx * m_pTiles->getWidth());

	// Flip Y due to how viewport is set.
	// ???TMH - Change height value to not be hard coded.
	m_fy = 160.0f - (m_fy * m_pTiles->getHeight());	

	// Determine depth of tile
	// ???KWB - Added to distinguish between secrets and normal floor tiles
	// ???KWB - Should be done in map file
	if ( (m_ID == ID_CAVE_STEPS) || (m_ID == ID_CAVE_ENTRANCE) )
	{
		m_eZ = Z_PLANE_SECRET;
	}
	else m_eZ = Z_PLANE_FLOOR;

	// ???KWB - Save the gamestate for now so I can figure out this crazy bug
	m_pGameState = pGameState;
}

//////////////////////////////////////////////////////////////////////////////
//	DESTRUCTOR
//////////////////////////////////////////////////////////////////////////////
cSpriteScreenTile::~cSpriteScreenTile()
{
}


//////////////////////////////////////////////////////////////////////////////
//
//	If tile is solid, make the sprite move back to it's previous location.
//
//////////////////////////////////////////////////////////////////////////////
bool cSpriteScreenTile::collide(cSprite* pSprite)
{
	BEGIN_ERRORHANDLER_GAME

	if (	(m_eCollisionMask & SPRITE_COLLIDE_SOLID) &&
			cSprite::collide(pSprite))
	{
		pSprite->moveBack();
		return true;
	}

	return false;
	
	END_ERRORHANDLER_GAME
}


//////////////////////////////////////////////////////////////////////////////
// Do nothing.
//////////////////////////////////////////////////////////////////////////////
void cSpriteScreenTile::reset()
{
}


//////////////////////////////////////////////////////////////////////////////
// Do nothing.
//////////////////////////////////////////////////////////////////////////////
void cSpriteScreenTile::update()
{}


//////////////////////////////////////////////////////////////////////////////
// Draw the sprite.
//////////////////////////////////////////////////////////////////////////////
void cSpriteScreenTile::draw()
{
	string szMessage;

	BEGIN_ERRORHANDLER_GAME
	// Make sure data is large enough to contain information for sprite.
	if (m_ID == -1)
		THROW_GAME("A map tile was never assigned an ID of what to draw.");

	// Tell the tile to draw itself at our coordinates.
	// ???KWB - Modified to handle cave-related secrets
	m_pTiles->draw(m_fx, m_fy, m_eZ, m_ID, m_yColorSet);
	END_ERRORHANDLER_GAME
}
 
// vi:set ts=3:
