//////////////////////////////////////////////////////////////////////////////
//
//	tiles.h
//	Defines for the cTiles class.
//
//	-	Holds the graphics for objects.
//	-	Tabs set to 3 spaces.
// 
//////////////////////////////////////////////////////////////////////////////

#ifndef __TILES_H__
#define __TILES_H__

#include "TextureImage.h"		// Hold tile images (for map's and screen's)
#include "GameException.h"
#include "inc/SpriteIDs.h"

// The maximum size a tile set (file)name can be.
const int MAX_TILE_NAME = 32;

// Table of conversions from ASCII value to tile ID in the character set
// (0xFF is invalid)
const BYTE charTileID[128] = 
{
	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x07
	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x0F
	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x17
	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x1F
	0x2C, 0x25, 0x29, 0xFF, 0x3A, 0x3B, 0x27, 0x26,		// 0x27
	0xFF, 0xFF, 0xFF, 0xFF, 0x24, 0x2B, 0x28, 0xFF,		// 0x2F
	0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,		// 0x37
	0x08, 0x09, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x2A,		// 0x3F
	0x3C, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F, 0x10,		// 0x47
	0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18,		// 0x4F
	0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F, 0x20,		// 0x57
	0x21, 0x22, 0x23, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x5F
	0xFF, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F, 0x10,		// 0x67
	0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18,		// 0x6F
	0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F, 0x20,		// 0x77
	0x21, 0x22, 0x23, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,		// 0x7F
};

class cTiles  
{
	///////////////////////////////////////////////////////////////////////////
	//	MEMBERS
	///////////////////////////////////////////////////////////////////////////
private:
	cTextureImage	m_oTileImages;		// Holds OpenGL textures for tiles.
	float				m_fWidth;			// Width of a tile in pixels.
	float				m_fHeight;			// Height of a tile in pixels.
	int				m_iTilesInImageX;	// Number of tiles in image across.
	int				m_iTilesInImageY;	// Number of tiles in image vertically.
	BYTE				m_yFirstColorSet;	// Number of the first color set.
	BYTE				m_yLastColorSet;	// Number of the last color set.

	///////////////////////////////////////////////////////////////////////////
	//	METHODS
	///////////////////////////////////////////////////////////////////////////
protected:
	cTiles(){}	// Default constructor non-creatable.

public:
	// Constructor
	cTiles(char szTileSetName[MAX_TILE_NAME], int iWidth, int iHeight);

	// Destructor
	virtual ~cTiles();
	
	// Renders a tile.
	void draw(float x, float y, float z, BYTE cTileID, BYTE yColorSet=0);

	// Renders a text string.
	void drawString(const string szMessage, float fx, float fy);


	///////////////////////////////////////////////////////////////////////////
	//	ACCESSORS
	///////////////////////////////////////////////////////////////////////////

	/*inline*/ float getWidth(); 	// Width of tiles.
	/*inline*/ float getHeight();	// Height of tiles.

	// Return first and last values for colors sets.
	/*inline*/ BYTE getFirstColorSet();
	/*inline*/ BYTE getLastColorSet();
};


#endif // __TILES_H__
// vi:set ts=3:
