#include "inc/system.h"
#include "titleScreen.h"

#include <jpeg/jpeg.h>

#define MIN(a, b) ( (a)<(b)? (a):(b) )
#define MAX(a, b) ( (a)>(b)? (a):(b) )

// image_draw() from:
// http://files.frashii.com/~sp00nz/Doom/files/BlackAura/tutes/2dgfx/tute05.html
void image_draw(kos_img_t *image, int x, int y)
{
	uint16 *src, *src_start;
	uint16 *dst, *dst_start;
	int drawW, drawH;
	int startX, endX;
	int startY, endY;

	if(!image)
		return;

	/* Find the starting coordinates, and abort if off screen */
	startX = MAX(x, 0);
	if(startX >= vid_mode->width)
		return;

	startY = MAX(y, 0);
	if(startY >= vid_mode->height)
		return;

	/* Find the ending coordinates */
	endX = MIN(x + image->w, vid_mode->width);
	if(endX <= 0)
		return;

	endY = MIN(y + image->h, vid_mode->height);
	if(endY <= 0)
		return;

	/* Width, height */
	drawW = endX - startX;
	drawH = endY - startY;

	/* Starting location for the source and destination */
	src_start = (uint16 *)image->data;
	dst_start = vram_s + startX + (startY * vid_mode->width);

	/* If we're off the screen, adjust the start position */
	if(x < 0)
		src_start += -x;
	if(y < 0)
		src_start += (-y * image->w);

	/* Draw the image */
	while(drawH--)
	{
		int dw = drawW;

		/* Copy the current image source, and nudge it down one line */
		src = src_start;
		dst = dst_start;
		src_start += image->w;
		dst_start += vid_mode->width;

		/* Draw the line */
		while(dw--)
			*dst++ = *src++;
	}
}

void draw_title_screen() {

	// load opening title
	kos_img_t title;
	jpeg_to_img("/rd/openlynks.jpg", 1, &title);
	image_draw(&title, (640-title.w)/2, (480-title.h)/2);
	kos_img_free(&title, 0);
		
	/*bfont_draw_str(vram_s+0*640+10,640,0, "Openlynks v0.9.5-pre2 ~DReAMcaST~");
	bfont_draw_str(vram_s+30*640+10,640,0,"Port(s) by: ");
	bfont_draw_str(vram_s+60*640+10,640,0,"Dominic Cerquetti");
	bfont_draw_str(vram_s+90*640+10,640,0,"Original Code by:");
	bfont_draw_str(vram_s+120*640+10,640,0,"  Nehe, Tronster Hartley and others");
	bfont_draw_str(vram_s+150*640+10,640,0,"Graphics by: John Kline");
	bfont_draw_str(vram_s+180*640+10,640,0,"http://openlynks.sf.net");

	bfont_draw_str(vram_s+220*640+10, 640, 0, "Loading...");*/
	
	printf("\n\n\n"
		   ">>---------------------------------\n"
		   ">>Openlynks v0.9.5-pre2 ~DReAMcaST~\n"
		   ">>---------------------------------\n");

	// sleep for 10 seconds
	// FIXME make this be 'press start' or something
	//thd_sleep(10000);
}
// vi:set ts=3:
